@@ -1,18 +1,16 @@
-;;; eselect-news.el --- Read Gentoo eselect news in Emacs -*- lexical-binding: t; -*-
+;;; eselect-news.el --- Read Gentoo eselect news -*- lexical-binding: t; -*-
 
 ;; Copyright (C) 2026 Marcin Kolenda
 ;;
-;; Author: Marcin Kolenda
-;; Maintainer: Marcin Kolenda
-;; Package-Version: 0.1.0
-;; Package-Revision: v0.1.0-0-gab4ecb45eef2
+;; Author: Marcin Kolenda <https://gitlab.com/cestrand>
+;; Maintainer: Marcin Kolenda <https://gitlab.com/cestrand>
+;; Package-Version: 20260222.1216
+;; Package-Revision: 562191c013a2
 ;; Package-Requires: ((emacs "27.1"))
-;; Keywords: tools, convenience
-;; URL: https://github.com/marcin/emacs-eselect-news
+;; Keywords: Gentoo, convenience
+;; URL: https://gitlab.com/cestrand/emacs-eselect-news
 ;; SPDX-License-Identifier: GPL-3.0-or-later
 ;;
-;; This file is not part of GNU Emacs.
-;;
 ;; eselect-news is free software: you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
 ;; the Free Software Foundation, either version 3 of the License, or
@@ -28,7 +26,7 @@
 
 ;;; Commentary:
 
-;; Minimal TUI for `eselect news read all`.
+;; Minimal UI for `eselect news read all`.
 ;;
 ;; Entry point:
 ;;   M-x eselect-news
@@ -167,7 +165,7 @@ Nil means keep the current face family."
   (setq eselect-news--fold-overlays nil))
 
 (defun eselect-news--isearch-open-overlay (ov)
-  "Make hidden text visible for isearch."
+  "Make hidden text visible (expose OV) for isearch."
   (overlay-put ov 'invisible nil))
 
 (defun eselect-news--isearch-open-overlay-temporary (ov hide-p)
